# libcollection
common data structures

[![PyPI version](https://badge.fury.io/py/jx-libcollection.svg)](https://badge.fury.io/py/jx-libcollection)


## stack

* ResizingArrayStack
* LinkedStack

## queue

* LinkedQueue
* SimpleLinkedQueue
* ResizingArrayQueue
* FixedCapacityArrayQueue

## Search

* SequentialSearchKVStore
* BinarySearchKVStore
* SeparateChainingHashKVStore
* LinearProbingKVStore
* BSTKVStore

## Sort

* bubble sort
* quick bubble sort
* selection sort
* quick selection sort
* recursive selection sort
* insertion sort
* shell sort
* merge sort
* quick sort
* heap sort

## Priority queue

* fixed size min priority queue
* fixed size max priority queue
* min priority queue
* max priority queue
